"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableauJwtGenerator = void 0;
require("reflect-metadata");
const inversify_1 = require("inversify");
const jwt = require("jsonwebtoken");
const uuid_1 = require("uuid");
let TableauJwtGenerator = class TableauJwtGenerator {
    constructor() {
        this.ALGORITHM = "HS256";
        this.TYPE = "JWT";
    }
    create(secretId, appId, subject, expiresInSeconds, scope, secretValue) {
        const exp = this.getExpirationSeconds(expiresInSeconds);
        const jti = (0, uuid_1.v4)();
        const header = this.createHeader(secretId, appId);
        const options = this.createOptions(header);
        const payload = this.createPayload(appId, subject, exp, jti, scope);
        return jwt.sign(payload, secretValue, options);
    }
    createHeader(kid, iss) {
        return {
            alg: this.ALGORITHM,
            kid,
            typ: this.TYPE,
            iss
        };
    }
    createOptions(header) {
        return {
            header
        };
    }
    createPayload(iss, sub, exp, jti, scp) {
        return {
            iss,
            sub,
            aud: "tableau",
            exp,
            jti,
            scp
        };
    }
    getExpirationSeconds(expiresInSeconds) {
        return Math.floor(new Date(new Date().getTime() + expiresInSeconds * 1000).getTime() / 1000);
    }
};
TableauJwtGenerator = __decorate([
    (0, inversify_1.injectable)()
], TableauJwtGenerator);
exports.TableauJwtGenerator = TableauJwtGenerator;
//# sourceMappingURL=tableau-jwt-generator.js.map